/*
 * Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */

#ifndef NFCTAGSWINDOW_H
#define NFCTAGSWINDOW_H

#include <QMainWindow>

//Forward declarations
class QTextEdit;
class QAction;
class NfcTagsDiscovery;

/*
 * This class is used to create the user interface for the 
 * Application.
 * You can exercise the following use cases from the menu 
 * options of the UI:
 * - Discover tags.
 * - Exchange data with tags.
 */
class NfcTagsWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit NfcTagsWindow(QWidget *parent = 0);
    
private:
    void initializeWindow();
    void addMenu();
    void closeEvent(QCloseEvent *event);

private slots:
    void startTagDiscovery();
    void stopTagDiscovery();
    void startNdefDiscovery();
    void stopNdefDiscovery();
    void changeMenu(int aOption);
    void clearText();
    void showMessage(QString aDisplayInfo);
    
private:
    QTextEdit *mDisplayInfo;
    NfcTagsDiscovery *mNfcTagsDiscovery;
    QString mText;

public:
    QAction *mStartTagDiscovery;
    QAction *mStopTagDiscovery;
    QAction *mStartNdefDiscovery;
    QAction *mStopNdefDiscovery;
    bool mDiscovery;
};

#endif // NFCTAGSWINDOW_H
